@@ -1,4 +1,4 @@
-write.tfl <- function (tfl, file)
+write.tfl <- function (tfl, file, encoding="")
 {
   if (! inherits(tfl, "tfl")) stop("'tfl' argument must be of class 'tfl'")
   if ( (length(file) != 1) || (! is.character(file)) )
@@ -6,5 +6,5 @@ write.tfl <- function (tfl, file)
   if (attr(tfl, "incomplete"))
     warning("saving incomplete type frequency list, which cannot be restored from disk file!")
   
-  write.table(tfl, file=auto.gzfile(file), quote=FALSE, sep="\t", row.names=FALSE, col.names=TRUE)
+  write.table(tfl, file=auto.gzfile(file, encoding=encoding), quote=FALSE, sep="\t", row.names=FALSE, col.names=TRUE)
 }
